import requests, os
from jennie.rule_engine.events.constants import *

def separate_via_comma(input_str):
    if input_str.replace(" ", "") == "":
        return []
    return input_str.replace(", ", ",").replace(" ,", ",").split(",")

def download_text_file(url):
    """
    Make a get api call, if params are present add params to url,
    if headers are present add headers to requests
    :param url: Request URL
    :param headers: Request Headers ( optional )
    :param params: Request Params ( optional )
    :return: API Call JSON Response.
    """
    response = requests.get(url)
    return response.text

def upload_text_file(text_file_path, app_name, type, user_key):
    """
    Upload text file to ASK SERVER
    :param text_file_path: Local path for text file.
    :param app_name: Application name
    :param type: Type of application
    :return: Uploaded File path
    """
    json_content = {
        "file_content": open(text_file_path, 'r').read(),
        "app_name": app_name,
        "filename": text_file_path.split("/")[-1],
        "type": type
    }
    text_res = requests.post(TEXT_UPLOAD_API, headers={"token": user_key},
                             json=json_content)
    return text_res.json()["payload"]["file_link"]

def list_all_files_from_folder(folder_path):
    # list to store files
    res = []

    # Iterate directory
    for path in os.listdir(folder_path):
        # check if current path is a file
        if os.path.isfile(os.path.join(folder_path, path)):
            res.append(path)
    return res